Using DaCy
==================

DaCy includes a series of tutorials on how to get started using DaCy as well how to use
DaCy for sentiment analysis and Hate speech Analysis and more. If you are unfamiliar with
DaCy/spaCy we recommend starting with the first guide.

.. toctree::
   :maxdepth: 3

   using_dacy.getting_started
   using_dacy.sentiment
   using_dacy.hate_speech
   using_dacy.augmentation


Additional Guides 
^^^^^^^^^^^^^^^^^^

Besides the above tutorials, DaCy also contains a few Google Colab tutorials:


.. |colab_fair| image:: https://colab.research.google.com/assets/colab-badge.svg
   :width: 100pt
   :target: https://colab.research.google.com/github/centre-for-humanities-computing/DaCy/blob/main/tutorials/dacy-robustness.ipynb


.. |colab_textd| image:: https://colab.research.google.com/assets/colab-badge.svg
   :width: 100pt
   :target: https://colab.research.google.com/github/centre-for-humanities-computing/DaCy/blob/main/textdescriptives_integration.ipynb



+---------------+----------------------------------------------------------------------------------------------------+
| Google Colab  | Content                                                                                            |
+===============+====================================================================================================+
| |colab_fair|  |  A guide on how to use augmenters to measure model robustness and biases.                          | 
+---------------+----------------------------------------------------------------------------------------------------+
| |colab_textd| |  A guide on how to extract text statistics such as text complexity using DaCy and textdescriptives | 
+---------------+----------------------------------------------------------------------------------------------------+